summaryrefslogtreecommitdiffstats
path: root/src/DotNetOpenAuth.OAuth2.Client
diff options
context:
space:
mode:
Diffstat (limited to 'src/DotNetOpenAuth.OAuth2.Client')
-rw-r--r--src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientBase.cs2
-rw-r--r--src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientCredentialApplicator.cs10
2 files changed, 6 insertions, 6 deletions
diff --git a/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientBase.cs b/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientBase.cs
index 2cfaede..dd34b12 100644
--- a/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientBase.cs
+++ b/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientBase.cs
@@ -278,7 +278,7 @@ namespace DotNetOpenAuth.OAuth2 {
/// <param name="secret">The client secret. May be <c>null</c></param>
/// <returns>The client credential applicator.</returns>
protected static ClientCredentialApplicator DefaultSecretApplicator(string secret) {
- return secret == null ? ClientCredentialApplicator.NoSecret() : ClientCredentialApplicator.SecretParameter(secret);
+ return secret == null ? ClientCredentialApplicator.NoSecret() : ClientCredentialApplicator.HttpBasic(secret);
}
/// <summary>
diff --git a/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientCredentialApplicator.cs b/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientCredentialApplicator.cs
index 67e7234..a95f3d0 100644
--- a/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientCredentialApplicator.cs
+++ b/src/DotNetOpenAuth.OAuth2.Client/OAuth2/ClientCredentialApplicator.cs
@@ -28,9 +28,9 @@ namespace DotNetOpenAuth.OAuth2 {
/// </summary>
/// <param name="clientSecret">The secret the client shares with the authorization server.</param>
/// <returns>The credential applicator to provide to the <see cref="ClientBase"/> instance.</returns>
- public static ClientCredentialApplicator SecretParameter(string clientSecret) {
+ public static ClientCredentialApplicator PostParameter(string clientSecret) {
Requires.NotNullOrEmpty(clientSecret, "clientSecret");
- return new SecretParameterApplicator(clientSecret);
+ return new PostParameterApplicator(clientSecret);
}
/// <summary>
@@ -92,17 +92,17 @@ namespace DotNetOpenAuth.OAuth2 {
/// <summary>
/// Authenticates the client via a client_secret parameter in the message.
/// </summary>
- private class SecretParameterApplicator : ClientCredentialApplicator {
+ private class PostParameterApplicator : ClientCredentialApplicator {
/// <summary>
/// The client secret.
/// </summary>
private readonly string secret;
/// <summary>
/// Initializes a new instance of the <see cref="SecretParameterApplicator"/> class.
/// </summary>
/// <param name="clientSecret">The client secret.</param>
- internal SecretParameterApplicator(string clientSecret) {
+ internal PostParameterApplicator(string clientSecret) {
Requires.NotNullOrEmpty(clientSecret, "clientSecret");
this.secret = clientSecret;
}
@@ -92,17 +92,17 @@ namespace DotNetOpenAuth.OAuth2 {
private readonly string secret;
/// <summary>
- /// Initializes a new instance of the <see cref="SecretParameterApplicator"/> class.
+ /// Initializes a new instance of the <see cref="PostParameterApplicator"/> class.
/// </summary>
/// <param name="clientSecret">The client secret.</param>